==========
Constraint
==========


The Constraint commands define constraints between regions of the model.

Create constraints
------------------

.. autoclass:: abaqus.Constraint.ConstraintModel.ConstraintModel
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::


Classes
-------

Constraint
~~~~~~~~~~

.. autoclass:: abaqus.Constraint.Constraint.Constraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

AdjustPoints
~~~~~~~~~~~~

.. autoclass:: abaqus.Constraint.AdjustPoints.AdjustPoints
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::


Coupling
~~~~~~~~

.. autoclass:: abaqus.Constraint.Coupling.Coupling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

DisplayBody
~~~~~~~~~~~

.. autoclass:: abaqus.Constraint.DisplayBody.DisplayBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

EmbeddedRegion
~~~~~~~~~~~~~~

.. autoclass:: abaqus.Constraint.EmbeddedRegion.EmbeddedRegion
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Equation
~~~~~~~~

.. autoclass:: abaqus.Constraint.Equation.Equation
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

MultipointConstraint
~~~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Constraint.MultipointConstraint.MultipointConstraint
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

RigidBody
~~~~~~~~~

.. autoclass:: abaqus.Constraint.RigidBody.RigidBody
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

ShellSolidCoupling
~~~~~~~~~~~~~~~~~~

.. autoclass:: abaqus.Constraint.ShellSolidCoupling.ShellSolidCoupling
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::

Tie
~~~

.. autoclass:: abaqus.Constraint.Tie.Tie
    :members:
    :special-members: __init__
    :show-inheritance:

    .. autoclasstoc::